class {{ python_class_name.pascal_case }}(abc.ABC):
    @property
    @abc.abstractmethod
    def _{{ abstract_property_name.snake_case }}(self) -> {{ property_type }}:
        raise NotImplementedError()

